==================
safetydance_django
==================


Add a short description here!


Description
===========

A longer description of your project goes here...


Note
====

This project has been set up using PyScaffold 3.2.3. For details and usage
information on PyScaffold see https://pyscaffold.org/.
